# Contributing

## Report a Bug or Make a Feature Request

Please go to the GitHub Issues page:
<https://github.com/kbandla/dpkt/issues>.

## Checkout the Code

```
git clone https://github.com/kbandla/dpkt.git
```

## Become a Developer

The dpkt package uses the 'GitHub Flow' model: [GitHub
Flow](http://scottchacon.com/2011/08/31/github-flow.html)

If you'd like to submit a PR to fix/improve dpkt, you should create a
'fork' of the repository and open a Pull Request (PR) and one of the
developers will review the PR and give feedback. The following page has good instructions on creating a PR from a fork: make a fork and then create a Pull Request <https://gist.github.com/Chaser324/ce0505fbed06b947d962>.

### New Feature or Bug

```
$ git checkout -b my-awesome
$ git push -u origin my-awesome
$ <code for a bit>; git push
$ <code for a bit>; git push
$ pytest dpkt (this will run all the tests)
```

- Go to github and hit 'New pull request'
- Someone reviews it and says 'AOK/give feedback and merges
